import React, { ChangeEvent, FC, useState } from 'react';
import Paper from '@mui/material/Paper';
import Typography from '@mui/material/Typography';
import Box from '@mui/material/Box';
import TextField from '@mui/material/TextField';
import InputAdornment from "@mui/material/InputAdornment";
import IconButton from '@mui/material/IconButton';
import Visibility from '@mui/icons-material/Visibility';
import VisibilityOff from '@mui/icons-material/VisibilityOff';
import { MenuItem, Select, SelectChangeEvent } from "@mui/material";

export const GlipSender: FC<{
  value: string;
  debug?: boolean
  edit?: boolean
  id?: string
  teamLink: string
  onChange: (value: string, isTeamLink?: boolean) => void
}> = ({ value, id,teamLink, debug, edit, onChange }) => {
  const handleChange = (e: ChangeEvent<HTMLInputElement>) => {
    onChange(e.target.value);
  };
  const [showPassword, setShowPassword] = React.useState(edit ? false : true);

  const handleClickShowPassword = () => setShowPassword((show) => !show);

  const handleMouseDownPassword = (event: React.MouseEvent<HTMLButtonElement>) => {
    event.preventDefault();
  };

  const [senderType, setSenderType] = useState('default');
  const handleChangeType = (e: SelectChangeEvent) => {
    setSenderType(e.target.value);
  };

  const handleChangeTeam = (event: React.ChangeEvent<HTMLInputElement>) => {
    onChange(event.target.value, true)
  };


  return (
    <Paper sx={{ p: 2, mb: 2 }}>
      <Typography variant="subtitle1" sx={{ mb: 1 }}>GlipSender</Typography>
      <Box>
        {!debug &&
          <>
            <Select value={senderType} sx={{ mb: 1 }} onChange={handleChangeType}>
              <MenuItem value="default">Use built-in bot (only supports team message)</MenuItem>
              <MenuItem value="custom">Use custom bot</MenuItem>
            </Select>
            {senderType === 'default' ? <>
                <Typography sx={{ mb: 2 }} variant="caption" component="div">
                  WFL Hub will send message via default bot <a style={{ color: '#f50057' }}>@David-Bot</a>
                </Typography>
                <TextField label="Team Link" fullWidth name="teamLink" id="teamLink" key="1" sx={{ mb: 4 }} value={teamLink}
                           onChange={handleChangeTeam}
                           defaultValue={edit ? 'https://app.ringcentral.com/l/messages/134751420422' : ''}/>
              </> :
              <>
                <Typography variant="caption" component="div" sx={{ mb: 2 }}>
                  WFL Hub will send messages via your <a style={{ color: '#f50057' }}
                                                         href="https://developers.ringcentral.com/guide/team-messaging/bots/walkthrough"
                                                         target="_blank" rel="noreferrer">RingCentral Bot</a>, please
                  fill in:
                </Typography>
                <TextField label="RingCentral Bot Client ID" fullWidth name="clientId"  key="2" id="clientId" sx={{ mb: 4 }}
                           defaultValue={edit ? '0w3wgTW5dkdfGjdseGDJ2y' : ''}/>
                <TextField label="RingCentral Bot Client Secret" sx={{ mb: 4 }}  key="3" name="clientSecret" id="clientSecret"
                           fullWidth
                           defaultValue={edit ? '6oGJ8Nko0socCF6rzFqKsk7FbNyT33ouDebXsOhACDhp' : ''}
                           type={showPassword ? 'text' : 'password'}
                           InputProps={{
                             endAdornment: (
                               <InputAdornment position="end">
                                 <IconButton
                                   aria-label="toggle password visibility"
                                   onClick={handleClickShowPassword}
                                   onMouseDown={handleMouseDownPassword}
                                   edge="end"
                                 >
                                   {showPassword ? <VisibilityOff/> : <Visibility/>}
                                 </IconButton>
                               </InputAdornment>
                             )
                           }}
                />
              </>}

          </>}
        <TextField label="Message format" placeholder="Please enter your message format"
                   value={value} name="message" fullWidth
                   onChange={handleChange} maxRows={5} minRows={2} multiline
        />
      </Box>
    </Paper>
  );
};
