/*
 * @Author       : Eleanor Mao
 * @Date         : 2024-04-10 09:14:31
 * @LastEditTime : 2024-04-10 09:14:31
 *
 * Copyright © RingCentral. All rights reserved.
 */


import jsYaml from 'js-yaml';
import { transformDSL } from './transform';

function compress(s: string, pre: string): string {
  s = unescape(encodeURIComponent(s));
  const arr = [];
  for (let i = 0; i < s.length; i++) {
    arr.push(s.charCodeAt(i));
  }
  // @ts-ignore
  const compressor = new Zopfli.RawDeflate(arr);
  const compressed = compressor.compress();
  // @ts-ignore
  return "http://www.plantuml.com/plantuml" + pre + encode64_(compressed);
}

export interface EventHandlerAction {
  actionType: string;
  targetState?: string;
  scriptSource?: string;
  transitionName?: string;
}

export interface Action {
  actionType: string;
  /* Script */
  scriptSource?: string;
  /* Chat */
  type?: string;
  token?: string;
  id?: string;
  question?: string;
  score?: null;
  /*EmailSender*/
  content?: string;
  subject?: string;
  to?: string;
  /*GlipSender*/
  url?: string;
  creatorId?: string;
  groupId?: string;
  message?: string;
}

export interface EventHandler {
  eventType: string;
  condition?: any;
  actions: EventHandlerAction[];
}

export interface State {
  name: string;
  actions: Action[];
  eventHandlers: EventHandler[];
}

export interface Definition {
  states: State[];
  workflowName: string;
}

export function Json2Preview(definition?: Definition): string {
  if (!definition) return '';
  try {
    return compress(transformDSL(definition), '/svg/');
  } catch (e) {
    console.error(e);
    return '';
  }
}

export function DSL2Json(input: string): Definition {
  return jsYaml.load(input) as Definition;
}

export function Json2Yml(json: any): string {
  return jsYaml.dump(json, { quotingType: '"' });
}

// @ts-ignore
window.ToJson = DSL2Json;
// @ts-ignore
window.transform = transformDSL;
